@@ -39,16 +39,16 @@
 #include <tqwhatsthis.h>
 #include <tqtimer.h>
 
-#include <kaction.h>
-#include <kpopupmenu.h>
-#include <klocale.h>
+#include <tdeaction.h>
+#include <tdepopupmenu.h>
+#include <tdelocale.h>
 #include <kinputdialog.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kdebug.h>
 #include <kiconloader.h>
-#include <kio/global.h>
-#include <kmessagebox.h>
-#include <kglobal.h>
+#include <tdeio/global.h>
+#include <tdemessagebox.h>
+#include <tdeglobal.h>
 #include <kpixmapeffect.h>
 
 
@@ -194,22 +194,22 @@ void K3bFillStatusDisplayWidget::paintEvent( TQPaintEvent* )
   if( d->showTime )
     docSizeText = d->doc->length().toString(false) + " " + i18n("min");
   else
-    docSizeText = KIO::convertSize( d->doc->size() );
+    docSizeText = TDEIO::convertSize( d->doc->size() );
 
   TQString overSizeText;
   if( d->cdSize.mode1Bytes() >= d->doc->size() )
     overSizeText = i18n("Available: %1 of %2")
       .arg( d->showTime
 	    ? i18n("%1 min").arg((K3b::Msf( cdSize*60*75 ) - d->doc->length()).toString(false))
-	    : KIO::convertSize( TQMAX( (cdSize * 1024LL * 1024LL) - (long long)d->doc->size(), 0LL ) ) )
+	    : TDEIO::convertSize( TQMAX( (cdSize * 1024LL * 1024LL) - (long long)d->doc->size(), 0LL ) ) )
       .arg( d->showTime
 	    ? i18n("%1 min").arg(K3b::Msf( cdSize*60*75 ).toString(false))
-	    : KIO::convertSizeFromKB( cdSize * 1024 ) );
+	    : TDEIO::convertSizeFromKB( cdSize * 1024 ) );
   else
     overSizeText = i18n("Capacity exceeded by %1")
       .arg( d->showTime
 	    ? i18n("%1 min").arg( (d->doc->length() - K3b::Msf( cdSize*60*75 ) ).toString(false))
-	    : KIO::convertSize( (long long)d->doc->size() - (cdSize * 1024LL * 1024LL) ) );
+	    : TDEIO::convertSize( (long long)d->doc->size() - (cdSize * 1024LL * 1024LL) ) );
   // ====================================================================================
 
   // draw the medium size marker
@@ -286,8 +286,8 @@ public:
 
   void maybeTip( const TQPoint& ) {
     tip( parentWidget()->rect(),
-	 KIO::convertSize( m_doc->size() ) +
-	 " (" + KGlobal::locale()->formatNumber( m_doc->size(), 0 ) + "), " +
+	 TDEIO::convertSize( m_doc->size() ) +
+	 " (" + TDEGlobal::locale()->formatNumber( m_doc->size(), 0 ) + "), " +
 	 m_doc->length().toString(false) + " " + i18n("min") +
 	 " (" + i18n("Right click for media sizes") + ")");
   }
@@ -299,22 +299,22 @@ private:
 class K3bFillStatusDisplay::Private
 {
 public:
-  KActionCollection* actionCollection;
-  KRadioAction* actionShowMinutes;
-  KRadioAction* actionShowMegs;
-  KRadioAction* actionAuto;
-  KRadioAction* action74Min;
-  KRadioAction* action80Min;
-  KRadioAction* action100Min;
-  KRadioAction* actionDvd4_7GB;
-  KRadioAction* actionDvdDoubleLayer;
+  TDEActionCollection* actionCollection;
+  TDERadioAction* actionShowMinutes;
+  TDERadioAction* actionShowMegs;
+  TDERadioAction* actionAuto;
+  TDERadioAction* action74Min;
+  TDERadioAction* action80Min;
+  TDERadioAction* action100Min;
+  TDERadioAction* actionDvd4_7GB;
+  TDERadioAction* actionDvdDoubleLayer;
   K3bRadioAction* actionCustomSize;
   K3bRadioAction* actionDetermineSize;
-  KAction* actionSaveUserDefaults;
-  KAction* actionLoadUserDefaults;
+  TDEAction* actionSaveUserDefaults;
+  TDEAction* actionLoadUserDefaults;
 
-  KPopupMenu* popup;
-  KPopupMenu* dvdPopup;
+  TDEPopupMenu* popup;
+  TDEPopupMenu* dvdPopup;
 
   TQToolButton* buttonMenu;
 
@@ -341,7 +341,7 @@ K3bFillStatusDisplay::K3bFillStatusDisplay( K3bDoc* doc, TQWidget *parent, const
 
   d->displayWidget = new K3bFillStatusDisplayWidget( doc, this );
 //   d->buttonMenu = new TQToolButton( this );
-//   d->buttonMenu->setIconSet( SmallIconSet("cdrom_unmount") );
+//   d->buttonMenu->setIconSet( SmallIconSet("media-optical-cdrom") );
 //   d->buttonMenu->setAutoRaise(true);
 //   TQToolTip::add( d->buttonMenu, i18n("Fill display properties") );
 //   connect( d->buttonMenu, TQT_SIGNAL(clicked()), TQT_TQOBJECT(this), TQT_SLOT(slotMenuButtonClicked()) );
@@ -372,37 +372,37 @@ K3bFillStatusDisplay::~K3bFillStatusDisplay()
 
 void K3bFillStatusDisplay::setupPopupMenu()
 {
-  d->actionCollection = new KActionCollection( this );
+  d->actionCollection = new TDEActionCollection( this );
 
   // we use a nother popup for the dvd sizes
-  d->popup = new KPopupMenu( this, "popup" );
-  d->dvdPopup = new KPopupMenu( this, "dvdpopup" );
+  d->popup = new TDEPopupMenu( this, "popup" );
+  d->dvdPopup = new TDEPopupMenu( this, "dvdpopup" );
 
-  d->actionShowMinutes = new KRadioAction( i18n("Minutes"), 0, TQT_TQOBJECT(this), TQT_SLOT(showTime()),
+  d->actionShowMinutes = new TDERadioAction( i18n("Minutes"), 0, TQT_TQOBJECT(this), TQT_SLOT(showTime()),
 					   d->actionCollection, "fillstatus_show_minutes" );
-  d->actionShowMegs = new KRadioAction( i18n("Megabytes"), 0, TQT_TQOBJECT(this), TQT_SLOT(showSize()),
+  d->actionShowMegs = new TDERadioAction( i18n("Megabytes"), 0, TQT_TQOBJECT(this), TQT_SLOT(showSize()),
 					d->actionCollection, "fillstatus_show_megabytes" );
 
   d->actionShowMegs->setExclusiveGroup( "show_size_in" );
   d->actionShowMinutes->setExclusiveGroup( "show_size_in" );
 
-  d->actionAuto = new KRadioAction( i18n("Auto"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotAutoSize()),
+  d->actionAuto = new TDERadioAction( i18n("Auto"), 0, TQT_TQOBJECT(this), TQT_SLOT(slotAutoSize()),
 				    d->actionCollection, "fillstatus_auto" );
-  d->action74Min = new KRadioAction( i18n("%1 MB").arg(650), 0, TQT_TQOBJECT(this), TQT_SLOT(slot74Minutes()),
+  d->action74Min = new TDERadioAction( i18n("%1 MB").arg(650), 0, TQT_TQOBJECT(this), TQT_SLOT(slot74Minutes()),
 				     d->actionCollection, "fillstatus_74minutes" );
-  d->action80Min = new KRadioAction( i18n("%1 MB").arg(700), 0, TQT_TQOBJECT(this), TQT_SLOT(slot80Minutes()),
+  d->action80Min = new TDERadioAction( i18n("%1 MB").arg(700), 0, TQT_TQOBJECT(this), TQT_SLOT(slot80Minutes()),
 				     d->actionCollection, "fillstatus_80minutes" );
-  d->action100Min = new KRadioAction( i18n("%1 MB").arg(880), 0, TQT_TQOBJECT(this), TQT_SLOT(slot100Minutes()),
+  d->action100Min = new TDERadioAction( i18n("%1 MB").arg(880), 0, TQT_TQOBJECT(this), TQT_SLOT(slot100Minutes()),
 				      d->actionCollection, "fillstatus_100minutes" );
-  d->actionDvd4_7GB = new KRadioAction( KIO::convertSizeFromKB((int)(4.4*1024.0*1024.0)), 0, TQT_TQOBJECT(this), TQT_SLOT(slotDvd4_7GB()),
+  d->actionDvd4_7GB = new TDERadioAction( TDEIO::convertSizeFromKB((int)(4.4*1024.0*1024.0)), 0, TQT_TQOBJECT(this), TQT_SLOT(slotDvd4_7GB()),
 					d->actionCollection, "fillstatus_dvd_4_7gb" );
-  d->actionDvdDoubleLayer = new KRadioAction( KIO::convertSizeFromKB((int)(8.0*1024.0*1024.0)),
+  d->actionDvdDoubleLayer = new TDERadioAction( TDEIO::convertSizeFromKB((int)(8.0*1024.0*1024.0)),
 					      0, TQT_TQOBJECT(this), TQT_SLOT(slotDvdDoubleLayer()),
 					      d->actionCollection, "fillstatus_dvd_double_layer" );
   d->actionCustomSize = new K3bRadioAction( i18n("Custom..."), 0, TQT_TQOBJECT(this), TQT_SLOT(slotCustomSize()),
 					    d->actionCollection, "fillstatus_custom_size" );
   d->actionCustomSize->setAlwaysEmitActivated(true);
-  d->actionDetermineSize = new K3bRadioAction( i18n("From Medium..."), "cdrom_unmount", 0,
+  d->actionDetermineSize = new K3bRadioAction( i18n("From Medium..."), "media-optical-cdrom", 0,
 					       TQT_TQOBJECT(this), TQT_SLOT(slotDetermineSize()),
 					       d->actionCollection, "fillstatus_size_from_disk" );
   d->actionDetermineSize->setAlwaysEmitActivated(true);
@@ -416,14 +416,14 @@ void K3bFillStatusDisplay::setupPopupMenu()
   d->actionCustomSize->setExclusiveGroup( "cd_size" );
   d->actionDetermineSize->setExclusiveGroup( "cd_size" );
 
-  d->actionLoadUserDefaults = new KAction( i18n("User Defaults"), "", 0,
+  d->actionLoadUserDefaults = new TDEAction( i18n("User Defaults"), "", 0,
 					   TQT_TQOBJECT(this), TQT_SLOT(slotLoadUserDefaults()),
 					   d->actionCollection, "load_user_defaults" );
-  d->actionSaveUserDefaults = new KAction( i18n("Save User Defaults"), "", 0,
+  d->actionSaveUserDefaults = new TDEAction( i18n("Save User Defaults"), "", 0,
 					   TQT_TQOBJECT(this), TQT_SLOT(slotSaveUserDefaults()),
 					   d->actionCollection, "save_user_defaults" );
 
-  KAction* dvdSizeInfoAction = new KAction( i18n("Why 4.4 instead of 4.7?"), "", 0,
+  TDEAction* dvdSizeInfoAction = new TDEAction( i18n("Why 4.4 instead of 4.7?"), "", 0,
 					    TQT_TQOBJECT(this), TQT_SLOT(slotWhy44()),
 					    d->actionCollection, "why_44_gb" );
 
@@ -542,13 +542,13 @@ void K3bFillStatusDisplay::slotCustomSize()
   TQString mbS = i18n("mb");
   TQString minS = i18n("min");
 
-  TQRegExp rx( "(\\d+\\" + KGlobal::locale()->decimalSymbol() + "?\\d*)(" + gbS + "|" + mbS + "|" + minS + ")?" );
+  TQRegExp rx( "(\\d+\\" + TDEGlobal::locale()->decimalSymbol() + "?\\d*)(" + gbS + "|" + mbS + "|" + minS + ")?" );
   bool ok;
   TQString size = KInputDialog::getText( i18n("Custom Size"),
 					i18n("<p>Please specify the size of the media. Use suffixes <b>gb</b>,<b>mb</b>, "
 					     "and <b>min</b> for <em>gigabytes</em>, <em>megabytes</em>, and <em>minutes</em>"
 					     " respectively."),
-					d->showDvdSizes ? TQString("4%14%2").arg(KGlobal::locale()->decimalSymbol()).arg(gbS) :
+					d->showDvdSizes ? TQString("4%14%2").arg(TDEGlobal::locale()->decimalSymbol()).arg(gbS) :
 					(d->showTime ? TQString("74")+minS : TQString("650")+mbS),
 					&ok, this, (const char*)0,
 					new TQRegExpValidator( rx, TQT_TQOBJECT(this) ) );
@@ -556,9 +556,9 @@ void K3bFillStatusDisplay::slotCustomSize()
     // determine size
     if( rx.exactMatch( size ) ) {
       TQString valStr = rx.cap(1);
-      if( valStr.endsWith( KGlobal::locale()->decimalSymbol() ) )
+      if( valStr.endsWith( TDEGlobal::locale()->decimalSymbol() ) )
 	valStr += "0";
-      double val = KGlobal::locale()->readNumber( valStr, &ok );
+      double val = TDEGlobal::locale()->readNumber( valStr, &ok );
       if( ok ) {
 	TQString s = rx.cap(2);
 	if( s == gbS || (s.isEmpty() && d->showDvdSizes) )
@@ -618,7 +618,7 @@ void K3bFillStatusDisplay::slotDetermineSize()
 void K3bFillStatusDisplay::slotLoadUserDefaults()
 {
   // load project specific values
-  KConfig* c = k3bcore->config();
+  TDEConfig* c = k3bcore->config();
   c->setGroup( "default " + d->doc->typeString() + " settings" );
 
   // defaults to megabytes
@@ -725,7 +725,7 @@ void K3bFillStatusDisplay::slotMediumChanged( K3bDevice::Device* )
 void K3bFillStatusDisplay::slotSaveUserDefaults()
 {
   // save project specific values
-  KConfig* c = k3bcore->config();
+  TDEConfig* c = k3bcore->config();
   c->setGroup( "default " + d->doc->typeString() + " settings" );
 
   c->writeEntry( "show minutes", d->showTime );
