@@ -32,8 +32,8 @@
 
 // Kde Includes
 #include <kiconloader.h>
-#include <kio/global.h>
-#include <klocale.h>
+#include <tdeio/global.h>
+#include <tdelocale.h>
 #include <kmimetype.h>
 #include <knuminput.h>
 #include <kurl.h>
@@ -69,13 +69,13 @@ K3bVcdTrackDialog::K3bVcdTrackDialog( K3bVcdDoc* _doc, TQPtrList<K3bVcdTrack>& t
 
         m_displayFileName->setText( selectedTrack->fileName() );
         m_displayLength->setText( selectedTrack->duration() );
-        m_displaySize->setText( KIO::convertSize( selectedTrack->size() ) );
+        m_displaySize->setText( TDEIO::convertSize( selectedTrack->size() ) );
         m_muxrate->setText( i18n( "%1 bit/s" ).arg( selectedTrack->muxrate() ) );
 
         if ( selectedTrack->isSegment() )
-            m_labelMimeType->setPixmap( SmallIcon( "image", KIcon::SizeMedium ) );
+            m_labelMimeType->setPixmap( SmallIcon( "image-x-generic", TDEIcon::SizeMedium ) );
         else
-            m_labelMimeType->setPixmap( SmallIcon( "video", KIcon::SizeMedium ) );
+            m_labelMimeType->setPixmap( SmallIcon( "video-x-generic", TDEIcon::SizeMedium ) );
 
         fillGui();
     }
@@ -265,9 +265,9 @@ void K3bVcdTrackDialog::fillPbcGui()
     for ( track = m_tracks.first(); track; track = m_tracks.next() ) {
         TQPixmap pm;
         if ( track->isSegment() )
-            pm = SmallIcon( "image" );
+            pm = SmallIcon( "image-x-generic" );
         else
-            pm = SmallIcon( "video" );
+            pm = SmallIcon( "video-x-generic" );
 
         TQString s = displayName( track );
         if ( track != selectedTrack )              // donot insert selectedTrack, it was as "ItSelf" inserted to the begin of map
@@ -296,7 +296,7 @@ void K3bVcdTrackDialog::fillPbcGui()
     }
 
     // add Event Disabled
-    TQPixmap pmDisabled = SmallIcon( "stop" );
+    TQPixmap pmDisabled = SmallIcon( "process-stop" );
     TQString txtDisabled = i18n( "Event Disabled" );
     m_pbc_previous->insertItem( pmDisabled, txtDisabled );
     m_pbc_next->insertItem( pmDisabled, txtDisabled );
@@ -305,7 +305,7 @@ void K3bVcdTrackDialog::fillPbcGui()
     m_comboAfterTimeout->insertItem( pmDisabled, txtDisabled );
 
     // add VideoCD End
-    TQPixmap pmEnd = SmallIcon( "cdrom_unmount" );
+    TQPixmap pmEnd = SmallIcon( "media-optical-cdrom" );
     TQString txtEnd = i18n( "VideoCD END" );
     m_pbc_previous->insertItem( pmEnd, txtEnd );
     m_pbc_next->insertItem( pmEnd, txtEnd );
